@@ -3,7 +3,7 @@ BEGIN {
   $App::DuckPAN::Cmd::Installdeps::AUTHORITY = 'cpan:DDG';
 }
 {
-  $App::DuckPAN::Cmd::Installdeps::VERSION = '0.104';
+  $App::DuckPAN::Cmd::Installdeps::VERSION = '0.105';
 }
 # ABSTRACT: Regular way to install requirements with tests
 
@@ -20,9 +20,9 @@ sub run {
 			"Found a dist.ini, suggesting a Dist::Zilla distribution",
 		);
 		$self->app->perl->cpanminus_install_error
-			if (system("dzil authordeps --missing 2>/dev/null | grep -vP '[^\\w:]' | cpanm"));
+			if (system("dzil authordeps --missing 2>/dev/null | grep -ve '^\\W' | cpanm"));
 		$self->app->perl->cpanminus_install_error
-			if (system("dzil listdeps --missing 2>/dev/null | grep -vP '[^\\w:]' | cpanm"));
+			if (system("dzil listdeps --missing 2>/dev/null | grep -ve '^\\W' | cpanm"));
 		$self->app->print_text(
 			"Everything fine!",
 		);
@@ -33,7 +33,6 @@ sub run {
 1;
 
 __END__
-
 =pod
 
 =head1 NAME
@@ -42,7 +41,7 @@ App::DuckPAN::Cmd::Installdeps - Regular way to install requirements with tests
 
 =head1 VERSION
 
-version 0.104
+version 0.105
 
 =head1 AUTHOR
 
@@ -56,3 +55,4 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
